# WARNING - Generated by {fusen} from /dev/flat_full.Rmd: do not edit by hand


#' Handle ANOVA Errors
#'
#' This function handles ANOVA errors and warnings during the ANOVA calculation process.
#'
#' @param l_TMB A list of fitted glmmTMB models.
#' @param group A character string indicating the group for which ANOVA is calculated.
#' @param ... Additional arguments to be passed to the \code{car::Anova} function.
#' 
#' @return A data frame containing ANOVA results for the specified group.
#' @export
#' 
#' @examples
#' l_tmb <- fitModelParallel(Sepal.Length ~ Sepal.Width + Petal.Length,
#'                           data = iris, group_by = "Species", n.cores = 1)
#' anova_res <- handleAnovaError(l_tmb, "setosa", type = "III")
#'
#' @importFrom car Anova
#' @export
handleAnovaError <- function(l_TMB, group, ...) {
  tryCatch(
    expr = {
      withCallingHandlers(
        car::Anova(l_TMB[[group]], ...),
        warning = function(w) {
          message(paste(Sys.time(), "warning for group", group, ":", conditionMessage(w)))
          invokeRestart("muffleWarning")
        })
    },
    error = function(e) {
      message(paste(Sys.time(), "error for group", group, ":", conditionMessage(e)))
      NULL
    }
  )
}


#' Perform ANOVA on Multiple glmmTMB Models in Parallel
#'
#' This function performs analysis of variance (ANOVA) on a list of \code{glmmTMB}
#' models in parallel for different groups specified in the list. It returns a list
#' of ANOVA results for each group.
#'
#' @param l_tmb A list of \code{glmmTMB} models, with model names corresponding to the groups.
#' @param ... Additional arguments passed to \code{\link[stats]{anova}} function.
#'
#' @return A list of ANOVA results for each group.
#' @importFrom stats setNames
#' @examples
#' # Perform ANOVA
#' data(iris)
#' l_tmb<- fitModelParallel( Sepal.Length ~ Sepal.Width  + Petal.Length, 
#'                          data = iris, group_by = "Species", n.cores = 1 )
#' anov_res <- anovaParallel(l_tmb , type = "III")
#' @importFrom stats anova
#' @export
anovaParallel <- function(l_tmb, ...) {
  l_group <- attributes(l_tmb)$names
  lapply(stats::setNames(l_group, l_group), function(group) handleAnovaError(l_tmb, group, ...))
}


